@@ -112,6 +112,24 @@ class CreateBaremetalPort(command.ShowOne):
             metavar='<port name>',
             help=_("Name of the port."))
 
+        parser.add_argument(
+            '--description',
+            dest='description',
+            metavar='<port description>',
+            help=_("An optional description for the port."))
+
+        parser.add_argument(
+            '--vendor',
+            dest='vendor',
+            metavar='<port vendor>',
+            help=_("An optional vendor for the port."))
+
+        parser.add_argument(
+            '--category',
+            dest='category',
+            metavar='<port category>',
+            help=_("An optional category for the port."))
+
         return parser
 
     def take_action(self, parsed_args):
@@ -132,7 +150,8 @@ class CreateBaremetalPort(command.ShowOne):
 
         field_list = ['address', 'uuid', 'extra', 'node_uuid', 'pxe_enabled',
                       'local_link_connection', 'portgroup_uuid',
-                      'physical_network', 'name']
+                      'physical_network', 'name', 'description', 'vendor',
+                      'category']
         fields = dict((k, v) for (k, v) in vars(parsed_args).items()
                       if k in field_list and v is not None)
         fields = utils.args_array_to_dict(fields, 'extra')
@@ -243,6 +262,24 @@ class UnsetBaremetalPort(command.Command):
             action='store_true',
             help=_("Unset the name for this port"))
 
+        parser.add_argument(
+            '--description',
+            dest='description',
+            action='store_true',
+            help=_("Unset the description for this port."))
+
+        parser.add_argument(
+            '--vendor',
+            dest='vendor',
+            action='store_true',
+            help=_("Unset the vendor for this port."))
+
+        parser.add_argument(
+            '--category',
+            dest='category',
+            action='store_true',
+            help=_("Unset the category for this port."))
+
         return parser
 
     def take_action(self, parsed_args):
@@ -266,6 +303,15 @@ class UnsetBaremetalPort(command.Command):
         if parsed_args.name:
             properties.extend(utils.args_array_to_patch('remove',
                               ['name']))
+        if parsed_args.description:
+            properties.extend(utils.args_array_to_patch('remove',
+                              ['description']))
+        if parsed_args.vendor:
+            properties.extend(utils.args_array_to_patch('remove',
+                              ['vendor']))
+        if parsed_args.category:
+            properties.extend(utils.args_array_to_patch('remove',
+                              ['category']))
 
         if properties:
             baremetal_client.port.update(parsed_args.port, properties)
@@ -357,6 +403,24 @@ class SetBaremetalPort(command.Command):
             dest='name',
             help=_("Set name for this port"))
 
+        parser.add_argument(
+            '--description',
+            metavar='<description>',
+            dest='description',
+            help=_("Set a description for this port"))
+
+        parser.add_argument(
+            '--vendor',
+            metavar='<vendor>',
+            dest='vendor',
+            help=_("Set a vendor for this port"))
+
+        parser.add_argument(
+            '--category',
+            metavar='<category>',
+            dest='category',
+            help=_("Set a category for this port"))
+
         return parser
 
     def take_action(self, parsed_args):
@@ -396,6 +460,18 @@ class SetBaremetalPort(command.Command):
         if parsed_args.name:
             port_name = ["name=%s" % parsed_args.name]
             properties.extend(utils.args_array_to_patch('add', port_name))
+        if parsed_args.description:
+            port_description = ["description=%s" % parsed_args.description]
+            properties.extend(utils.args_array_to_patch('add',
+                                                        port_description))
+        if parsed_args.vendor:
+            port_vendor = ["vendor=%s" % parsed_args.vendor]
+            properties.extend(utils.args_array_to_patch('add',
+                                                        port_vendor))
+        if parsed_args.category:
+            port_category = ["category=%s" % parsed_args.category]
+            properties.extend(utils.args_array_to_patch('add',
+                                                        port_category))
 
         if properties:
             baremetal_client.port.update(parsed_args.port, properties)
